# == Class: snmpd::params
#
# This is a container class holding default parameters for snmpd module.
#
class snmpd::params {
  $snmpdrun      = 'yes'
  $trapdrun      = 'no'
  $secname       = 'snmp'
  $allowed_hosts = [ '127.0.0.1' ]
  $community     = 'public'
  $syslocation   = '<LOCATION>'
  $syscontact    = '<CONTACT>'
  $sysservices   = '74'

  $systemd       = '/etc/systemd/system/snmpd.service.d'

  case $::operatingsystem {
    /(?i:debian|devuan|ubuntu)/: {
      $snmpd_package_name = 'snmpd'
      $snmpd_package_deps = [ 'snmp-mibs-downloader' ]
      $snmpd_service_name = 'snmpd'
      $snmpd_user_name    = 'root'
      $snmpd_group_name   = 'root'
      $snmpd_sysconfig    = '/etc/default/snmpd'
      $snmpd_systemd      = "${systemd}/override.conf"
      $snmpd_options      = '-LS3d'
      $snmpd_config       = '/etc/snmp/snmpd.conf'
      $include            = '/etc/snmp/snmpd_local.conf'
    }
    /(?i:fedora|redhat)/       : {
      $snmpd_package_name = 'net-snmp'
      $snmpd_package_deps = [ 'net-snmp-utils' ]
      $snmpd_service_name = 'snmpd'
      $snmpd_user_name    = 'root'
      $snmpd_group_name   = 'root'
      $snmpd_sysconfig    = '/etc/sysconfig/snmpd'
      $snmpd_systemd      = "${systemd}/override.conf"
      $snmpd_options      = '-LS3d'
      $snmpd_config       = '/etc/snmp/snmpd.conf'
      $include            = '/etc/snmp/snmpd_local.conf'
    }
    /(?i:centos)/              : {
      $snmpd_package_name = 'net-snmp'
      $snmpd_package_deps = [ 'net-snmp-utils' ]
      $snmpd_service_name = 'snmpd'
      $snmpd_user_name    = 'root'
      $snmpd_group_name   = 'root'
      $snmpd_sysconfig    = '/etc/sysconfig/snmpd.options'
      $snmpd_systemd      = "${systemd}/override.conf"
      $snmpd_options      = '-Lsd'
      $snmpd_config       = '/etc/snmp/snmpd.conf'
      $include            = '/etc/snmp/snmpd_local.conf'
    }
    default                    : {
      fail("Module ${module_name} is not supported on ${::operatingsystem}")
    }
  }
}
# EOF
