# -*- ruby -*-

require 'serverspec'

set :backend, :exec

describe 'Packages' do
  [
    'net-snmp',
    'net-snmp-utils'
  ].each do |pkg|
    describe package(pkg) do
      it { should be_installed }
    end
  end
end

describe 'Service' do
  describe service('snmpd') do
    it { should be_enabled }
    it { should be_running }
  end
end

describe 'Configuration files (snmpd.conf)' do
  describe file('/etc/snmp/snmpd.conf') do
    it { should exist }
    it { should be_owned_by 'root' }
    it { should be_grouped_into 'root' }
    it { should be_mode 644 }
    it { should contain 'test' }
    it { should contain '127.0.0.1' }
    it { should contain '10.0.0.0/8' }
    it { should contain 'private' }
    it { should contain 'kitchen' }
    it { should contain 'root' }
  end
end

describe 'Script files' do
  %w[
    powerdns.php
    vp-distro
    vp-hardware
    vp-manufacturer
    vp-ntp-client
    vp-osupdate
    vp-serial
  ].each do |script|
    describe file("/usr/local/bin/#{script}") do
      it { should exist }
      it { should be_owned_by 'root' }
      it { should be_grouped_into 'root' }
      it { should be_mode 755 }
    end
  end
end
# EOF
